@@ -1,12 +1,13 @@
-use crate::errors::YdbResult;
 use crate::client_common::DBCredentials;
 use crate::client_table::TableClient;
 use crate::discovery::Discovery;
+use crate::errors::YdbResult;
 use crate::load_balancer::SharedLoadBalancer;
 use crate::middlewares::AuthService;
 use crate::waiter::Waiter;
 
 use std::sync::Arc;
+use std::time::Duration;
 
 use tracing::trace;
 
@@ -17,6 +18,7 @@ pub struct Client {
     credentials: DBCredentials,
     load_balancer: SharedLoadBalancer,
     discovery: Arc<Box<dyn Discovery>>,
+    timeouts: TimeoutSettings,
 }
 
 impl Client {
@@ -30,12 +32,22 @@ impl Client {
             credentials,
             load_balancer: SharedLoadBalancer::new(discovery.as_ref()),
             discovery,
+            timeouts: TimeoutSettings::default(),
         });
     }
 
     /// Create instance of client for table service
     pub fn table_client(&self) -> TableClient {
-        return TableClient::new(self.credentials.clone(), self.discovery.clone());
+        return TableClient::new(
+            self.credentials.clone(),
+            self.discovery.clone(),
+            self.timeouts,
+        );
+    }
+
+    pub fn with_timeouts(mut self, timeouts: TimeoutSettings) -> Self {
+        self.timeouts = timeouts;
+        return self;
     }
 
     /// Wait initialization completed
@@ -53,3 +65,19 @@ impl Client {
         return Ok(());
     }
 }
+
+const DEFAULT_OPERATION_TIMEOUT: Duration = Duration::from_secs(1);
+
+#[non_exhaustive]
+#[derive(Copy, Clone, Debug)]
+pub struct TimeoutSettings {
+    pub operation_timeout: Duration,
+}
+
+impl Default for TimeoutSettings {
+    fn default() -> Self {
+        return TimeoutSettings {
+            operation_timeout: DEFAULT_OPERATION_TIMEOUT,
+        };
+    }
+}
